@@ -5,10 +5,10 @@ HUD Gym SDK - A Python SDK for interacting with HUD environments.
 from __future__ import annotations
 
 from . import agent, env, gym, settings, task, taskset, types, utils
-from .job import create_job, job, load_job
+from .job import create_job, job, load_job, run_job
 from .taskset import load_taskset
 
-__version__ = "0.2.1"
+__version__ = "0.2.2"
 
 __all__ = [
     "agent",
@@ -18,6 +18,7 @@ __all__ = [
     "job",
     "load_job",
     "load_taskset",
+    "run_job",
     "settings",
     "task",
     "taskset",
