@@ -1,7 +1,8 @@
 from .base import Agent
 from .claude import ClaudeAgent
 from .operator import OperatorAgent
+from .langchain import LangchainAgent
 
 from hud.adapters import OperatorAdapter, ClaudeAdapter
 
-__all__ = ["Agent", "ClaudeAgent", "OperatorAgent", "OperatorAdapter", "ClaudeAdapter"]
+__all__ = ["Agent", "ClaudeAgent", "OperatorAgent", "OperatorAdapter", "ClaudeAdapter", "LangchainAgent"]
